pub enum BodyStatus {
Disabled,
Static,
Dynamic,
Kinematic,
}Expand description
The status of a body.
Variants
Disabled
The body is disabled and ignored by the physics engine.
Static
The body is static and thus cannot move.
Dynamic
The body is dynamic and thus can move and is subject to forces.
Kinematic
The body is kinematic so its velocity is controlled by the user and it is not affected by forces and constraints.