CartesianJoint

Struct CartesianJoint 

pub struct CartesianJoint<N>
where N: RealField + Copy,
{ /* private fields */ }
A joint that allows only all the translational degrees of freedom between two multibody links.

Implementations

Source

impl<N> CartesianJoint<N>
where N: RealField + Copy,

pub fn new( position: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> CartesianJoint<N>

Create a cartesian joint with an initial position given by position.