pub struct MaterialContext<'a, N>{
pub shape: &'a (dyn Shape<N> + 'static),
pub position: &'a Isometry<N, Unit<Complex<N>>, 2>,
pub contact: &'a TrackedContact<N>,
pub is_first: bool,
}Expand description
The context for determining the local material properties at a contact.
Fields
shape: &'a (dyn Shape<N> + 'static)The shape of the collider involved in the contact.
position: &'a Isometry<N, Unit<Complex<N>>, 2>The position of the collider involved in the contact.
contact: &'a TrackedContact<N>The contact.
is_first: boolWhether the bodies (and collider) in this structure are the first one involved in the contact.
This is false if the body involved in the contact is the second one.