pub struct MaterialHandle<N>(/* private fields */)
where
N: RealField + Copy;Expand description
A shared handle to an abstract shape.
This can be mutated using COW.
Implementations
Sourceimpl<N> MaterialHandle<N>
impl<N> MaterialHandle<N>
Sourcepub fn new<S>(material: S) -> MaterialHandle<N>
pub fn new<S>(material: S) -> MaterialHandle<N>
Creates a sharable shape handle from a shape.
Methods from Deref<Target = dyn Material<N>>
Sourcepub fn is<__T>(&self) -> boolwhere
__T: Material<N>,
pub fn is<__T>(&self) -> boolwhere
__T: Material<N>,
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast_rc<__T>(
self: Rc<dyn Material<N>>,
) -> Result<Rc<__T>, Rc<dyn Material<N>>>where
__T: Material<N>,
pub fn downcast_rc<__T>(
self: Rc<dyn Material<N>>,
) -> Result<Rc<__T>, Rc<dyn Material<N>>>where
__T: Material<N>,
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T>(&self) -> Option<&__T>where
__T: Material<N>,
pub fn downcast_ref<__T>(&self) -> Option<&__T>where
__T: Material<N>,
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.