pub struct CsMatrix<T, R = Dynamic, C = Dynamic, S = CsVecStorage<T, R, C>>{ /* private fields */ }Expand description
A compressed sparse column matrix.
Implementations
Sourceimpl<T, R, C> CsMatrix<T, R, C>
impl<T, R, C> CsMatrix<T, R, C>
Sourcepub fn new_uninitialized_generic(
nrows: R,
ncols: C,
nvals: usize,
) -> CsMatrix<T, R, C>
pub fn new_uninitialized_generic( nrows: R, ncols: C, nvals: usize, ) -> CsMatrix<T, R, C>
Creates a new compressed sparse column matrix with the specified dimension and
nvals possible non-zero values.
Sourceimpl<T, R, C, S> CsMatrix<T, R, C, S>
impl<T, R, C, S> CsMatrix<T, R, C, S>
Sourcepub fn is_sorted(&self) -> bool
pub fn is_sorted(&self) -> bool
Should always return true.
This method is generally used for debugging and should typically not be called in user code.
This checks that the row inner indices of this matrix are sorted. It takes O(n) time,
where nisself.len(). All operations of CSC matrices on nalgebra assume, and will return, sorted indices. If at any time this is_sortedmethod returnsfalse`, then, something went wrong
and an issue should be open on the nalgebra repository with details on how to reproduce
this.
Sourceimpl<T, R, C, S> CsMatrix<T, R, C, S>
impl<T, R, C, S> CsMatrix<T, R, C, S>
Sourcepub fn values_mut(&mut self) -> impl Iterator<Item = &mut T>
pub fn values_mut(&mut self) -> impl Iterator<Item = &mut T>
Iterator through all the mutable values of this sparse matrix.
Sourceimpl<T, D, S> CsMatrix<T, D, D, S>
impl<T, D, S> CsMatrix<T, D, D, S>
Sourcepub fn solve_lower_triangular<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
DefaultAllocator: Allocator<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<D, R2>,
pub fn solve_lower_triangular<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
DefaultAllocator: Allocator<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<D, R2>,
Solve a lower-triangular system with a dense right-hand-side.
Sourcepub fn tr_solve_lower_triangular<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
DefaultAllocator: Allocator<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<D, R2>,
pub fn tr_solve_lower_triangular<R2, C2, S2>(
&self,
b: &Matrix<T, R2, C2, S2>,
) -> Option<Matrix<T, R2, C2, <DefaultAllocator as Allocator<T, R2, C2>>::Buffer>>where
R2: Dim,
C2: Dim,
S2: Storage<T, R2, C2>,
DefaultAllocator: Allocator<T, R2, C2>,
ShapeConstraint: SameNumberOfRows<D, R2>,
Solve a lower-triangular system with self transposed and a dense right-hand-side.
Sourcepub fn solve_lower_triangular_mut<R2, C2, S2>(
&self,
b: &mut Matrix<T, R2, C2, S2>,
) -> bool
pub fn solve_lower_triangular_mut<R2, C2, S2>( &self, b: &mut Matrix<T, R2, C2, S2>, ) -> bool
Solve in-place a lower-triangular system with a dense right-hand-side.
Sourcepub fn tr_solve_lower_triangular_mut<R2, C2, S2>(
&self,
b: &mut Matrix<T, R2, C2, S2>,
) -> bool
pub fn tr_solve_lower_triangular_mut<R2, C2, S2>( &self, b: &mut Matrix<T, R2, C2, S2>, ) -> bool
Solve a lower-triangular system with self transposed and a dense right-hand-side.
Sourcepub fn solve_lower_triangular_cs<D2, S2>(
&self,
b: &CsMatrix<T, D2, Const<1>, S2>,
) -> Option<CsMatrix<T, D2, Const<1>>>where
D2: Dim,
S2: CsStorage<T, D2>,
DefaultAllocator: Allocator<bool, D> + Allocator<T, D2> + Allocator<usize, D2>,
ShapeConstraint: SameNumberOfRows<D, D2>,
pub fn solve_lower_triangular_cs<D2, S2>(
&self,
b: &CsMatrix<T, D2, Const<1>, S2>,
) -> Option<CsMatrix<T, D2, Const<1>>>where
D2: Dim,
S2: CsStorage<T, D2>,
DefaultAllocator: Allocator<bool, D> + Allocator<T, D2> + Allocator<usize, D2>,
ShapeConstraint: SameNumberOfRows<D, D2>,
Solve a lower-triangular system with a sparse right-hand-side.