Collider

Struct Collider 

pub struct Collider<N, Handle>(/* private fields */)
where
    N: RealField + Copy,
    Handle: BodyHandle;
A geometric entity that can be attached to a body so it can be affected by contacts and proximity queries.

Implementations

Source

impl<N, Handle> Collider<N, Handle>
where N: RealField + Copy, Handle: BodyHandle,

pub fn removal_data(&self) -> Option<ColliderRemovalData<N, Handle>>

Computes the data that needs to be returned once this collider has been removed from a collider set.

pub fn user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>

The user-data attached to this collider.

pub fn user_data_mut( &mut self, ) -> Option<&mut (dyn Any + Send + Sync + 'static)>

Mutable reference to the user-data attached to this collider.

pub fn set_user_data( &mut self, data: Option<Box<dyn Any + Send + Sync>>, ) -> Option<Box<dyn Any + Send + Sync>>

Sets the user-data attached to this collider.

pub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>

Replaces the user-data of this collider by None and returns the old value.

pub fn margin(&self) -> N

The collision margin surrounding this collider.

pub fn set_margin(&mut self, margin: N)

Sets the marging on this collider’s shapes.

pub fn clear_update_flags(&mut self)

Clears all the internal flags tracking changes made to this collider.

pub fn density(&self) -> N

The density of this collider.

pub fn body(&self) -> Handle

Handle to the body this collider is attached to.

pub fn anchor(&self) -> &ColliderAnchor<N, Handle>

The anchor attaching this collider with a body part or deformable body.

pub fn position_wrt_body(&self) -> Isometry<N, Unit<Complex<N>>, 2>

The position of this collider geometry wrt. the body it is attached to.

pub fn body_part(&self, subshape_id: usize) -> BodyPartHandle<Handle>

Handle to the body part containing the given subshape of this collider’s shape.

pub fn material(&self) -> &(dyn Material<N> + 'static)

The material of this collider.

pub fn material_mut(&mut self) -> &mut (dyn Material<N> + 'static)

A mutable reference to this collider’s material.

If the material is shared, then an internal clone is performed before returning the mutable reference (this effectively calls the Arc::make_mut method to get a copy-on-write behavior).

pub fn is_sensor(&self) -> bool

Returns true if this collider is a sensor.

pub fn is_ccd_enabled(&self) -> bool

Returns true if this collider is subjected to Continuous Collision Detection (CCD).

pub fn enable_ccd(&mut self, enabled: bool)

Enables or disables Continuous Collision Detection (CCD) for this collider.

pub fn graph_index(&self) -> Option<NodeIndex<usize>>

This collider’s non-stable graph index.

This index may change whenever a collider is removed from the world.

pub fn set_graph_index(&mut self, index: Option<NodeIndex<usize>>)

Sets the collider unique but non-stable graph index.

pub fn proxy_handle(&self) -> Option<BroadPhaseProxyHandle>

The collider’s broad phase proxy unique identifier.

pub fn set_proxy_handle(&mut self, handle: Option<BroadPhaseProxyHandle>)

Sets the collider’s broad phase proxy unique identifier.

pub fn position(&self) -> &Isometry<N, Unit<Complex<N>>, 2>

The collider position.

pub fn set_position(&mut self, pos: Isometry<N, Unit<Complex<N>>, 2>)

Sets the position of the collider.

pub fn set_position_with_prediction( &mut self, position: Isometry<N, Unit<Complex<N>>, 2>, prediction: Isometry<N, Unit<Complex<N>>, 2>, )

Sets the position of the collider.

pub fn set_deformations(&mut self, coords: &[N])

Deforms the underlying shape if possible.

Panics if the shape is not deformable.

pub fn shape(&self) -> &(dyn Shape<N> + 'static)

This collider’s shape.

pub fn shape_handle(&self) -> &ShapeHandle<N>

This collider’s shape.

pub fn set_shape(&mut self, shape: ShapeHandle<N>)

Sets this collider’s shape.

pub fn collision_groups(&self) -> &CollisionGroups

The collision groups of the collider.

pub fn set_collision_groups(&mut self, groups: CollisionGroups)

Sets the collision groups of this collider.

pub fn query_type(&self) -> GeometricQueryType<N>

Returns the kind of queries this collider is expected to emit.

pub fn set_query_type(&mut self, query_type: GeometricQueryType<N>)

Sets the GeometricQueryType of the collider. Use CollisionWorld::set_query_type to use this method.