ColliderDesc

Struct ColliderDesc 

pub struct ColliderDesc<N>
where N: RealField + Copy,
{ /* private fields */ }
A non-deformable collider builder.

See https://www.nphysics.org/rigid_body_simulations_with_contacts/#colliders for details.

Implementations

Source

impl<N> ColliderDesc<N>
where N: RealField + Copy,

pub fn new(shape: ShapeHandle<N>) -> ColliderDesc<N>

Creates a new collider builder with the given shape.

pub fn default_margin() -> N

The default margin surrounding a collider: 0.01

pub fn user_data(self, data: impl UserData) -> ColliderDesc<N>

Sets a user-data to be attached to the object being built.

pub fn set_user_data( &mut self, data: Option<impl UserData>, ) -> &mut ColliderDesc<N>

Sets the user-data to be attached to the object being built.

pub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>

Reference to the user-data to be attached to the object being built.

pub fn rotation(self, angle: N) -> ColliderDesc<N>

pub fn set_rotation(&mut self, angle: N) -> &mut ColliderDesc<N>

pub fn translation( self, vector: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> ColliderDesc<N>

pub fn set_translation( &mut self, vector: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> &mut ColliderDesc<N>

pub fn material(self, material: MaterialHandle<N>) -> ColliderDesc<N>

pub fn set_material( &mut self, material: MaterialHandle<N>, ) -> &mut ColliderDesc<N>

pub fn shape(self, shape: ShapeHandle<N>) -> ColliderDesc<N>

pub fn set_shape(&mut self, shape: ShapeHandle<N>) -> &mut ColliderDesc<N>

pub fn margin(self, margin: N) -> ColliderDesc<N>

pub fn set_margin(&mut self, margin: N) -> &mut ColliderDesc<N>

pub fn density(self, density: N) -> ColliderDesc<N>

pub fn set_density(&mut self, density: N) -> &mut ColliderDesc<N>

pub fn collision_groups( self, collision_groups: CollisionGroups, ) -> ColliderDesc<N>

pub fn set_collision_groups( &mut self, collision_groups: CollisionGroups, ) -> &mut ColliderDesc<N>

pub fn linear_prediction(self, linear_prediction: N) -> ColliderDesc<N>

pub fn set_linear_prediction( &mut self, linear_prediction: N, ) -> &mut ColliderDesc<N>

pub fn angular_prediction(self, angular_prediction: N) -> ColliderDesc<N>

pub fn set_angular_prediction( &mut self, angular_prediction: N, ) -> &mut ColliderDesc<N>

pub fn sensor(self, is_sensor: bool) -> ColliderDesc<N>

pub fn set_is_sensor(&mut self, is_sensor: bool) -> &mut ColliderDesc<N>

pub fn position( self, position: Isometry<N, Unit<Complex<N>>, 2>, ) -> ColliderDesc<N>

pub fn set_position( &mut self, position: Isometry<N, Unit<Complex<N>>, 2>, ) -> &mut ColliderDesc<N>

pub fn ccd_enabled(self, ccd_enabled: bool) -> ColliderDesc<N>

pub fn set_ccd_enabled(&mut self, ccd_enabled: bool) -> &mut ColliderDesc<N>

pub fn get_rotation(&self) -> N

pub fn get_shape(&self) -> &(dyn Shape<N> + 'static)

pub fn get_translation( &self, ) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>

pub fn get_material(&self) -> Option<&(dyn Material<N> + 'static)>

pub fn get_margin(&self) -> N

pub fn get_density(&self) -> N

pub fn get_collision_groups(&self) -> CollisionGroups

pub fn get_linear_prediction(&self) -> N

pub fn get_angular_prediction(&self) -> N

pub fn is_sensor(&self) -> bool

pub fn get_ccd_enabled(&self) -> bool

pub fn get_position(&self) -> &Isometry<N, Unit<Complex<N>>, 2>

pub fn build<Handle>( &self, parent_handle: BodyPartHandle<Handle>, ) -> Collider<N, Handle>
where Handle: BodyHandle,

Build a collider and configure it to be attached to the given parent body part.