pub struct MassSpringSystemDesc<'a, N>{ /* private fields */ }Expand description
A builder for mass-spring systems.
Implementations
Sourceimpl<'a, N> MassSpringSystemDesc<'a, N>
impl<'a, N> MassSpringSystemDesc<'a, N>
Sourcepub fn from_polyline(polyline: &'a Polyline<N>) -> MassSpringSystemDesc<'a, N>
pub fn from_polyline(polyline: &'a Polyline<N>) -> MassSpringSystemDesc<'a, N>
Create a mass-constraints system form a polygonal line.
Sourcepub fn quad(subdiv_x: usize, subdiv_y: usize) -> MassSpringSystemDesc<'a, N>
pub fn quad(subdiv_x: usize, subdiv_y: usize) -> MassSpringSystemDesc<'a, N>
Create a quad-shaped body.
Sourcepub fn user_data(self, data: impl UserData) -> MassSpringSystemDesc<'a, N>
pub fn user_data(self, data: impl UserData) -> MassSpringSystemDesc<'a, N>
Sets a user-data to be attached to the object being built.
Sourcepub fn set_user_data(
&mut self,
data: Option<impl UserData>,
) -> &mut MassSpringSystemDesc<'a, N>
pub fn set_user_data( &mut self, data: Option<impl UserData>, ) -> &mut MassSpringSystemDesc<'a, N>
Sets the user-data to be attached to the object being built.
Sourcepub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
pub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
Reference to the user-data to be attached to the object being built.
Sourcepub fn clear_kinematic_nodes(&mut self) -> &mut MassSpringSystemDesc<'a, N>
pub fn clear_kinematic_nodes(&mut self) -> &mut MassSpringSystemDesc<'a, N>
Mark all nodes as non-kinematic.
pub fn plasticity( self, strain_threshold: N, creep: N, max_force: N, ) -> MassSpringSystemDesc<'a, N>
pub fn set_plasticity( &mut self, strain_threshold: N, creep: N, max_force: N, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn kinematic_nodes(self, nodes: &[usize]) -> MassSpringSystemDesc<'a, N>
pub fn set_nodes_kinematic( &mut self, nodes: &[usize], ) -> &mut MassSpringSystemDesc<'a, N>
pub fn gravity_enabled( self, gravity_enabled: bool, ) -> MassSpringSystemDesc<'a, N>
pub fn enable_gravity( &mut self, gravity_enabled: bool, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn stiffness(self, stiffness: N) -> MassSpringSystemDesc<'a, N>
pub fn set_stiffness( &mut self, stiffness: N, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn sleep_threshold( self, sleep_threshold: Option<N>, ) -> MassSpringSystemDesc<'a, N>
pub fn set_sleep_threshold( &mut self, sleep_threshold: Option<N>, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn damping_ratio(self, damping_ratio: N) -> MassSpringSystemDesc<'a, N>
pub fn set_damping_ratio( &mut self, damping_ratio: N, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn mass(self, mass: N) -> MassSpringSystemDesc<'a, N>
pub fn set_mass(&mut self, mass: N) -> &mut MassSpringSystemDesc<'a, N>
pub fn status(self, status: BodyStatus) -> MassSpringSystemDesc<'a, N>
pub fn set_status( &mut self, status: BodyStatus, ) -> &mut MassSpringSystemDesc<'a, N>
pub fn get_plasticity_strain_threshold(&self) -> N
pub fn get_plasticity_creep(&self) -> N
pub fn get_plasticity_max_force(&self) -> N
pub fn get_kinematic_nodes(&self) -> &[usize]
pub fn is_gravity_enabled(&self) -> bool
pub fn get_stiffness(&self) -> N
pub fn get_sleep_threshold(&self) -> Option<N>
pub fn get_damping_ratio(&self) -> N
pub fn get_mass(&self) -> N
pub fn get_status(&self) -> BodyStatus
Sourcepub fn build(&self) -> MassSpringSystem<N>
pub fn build(&self) -> MassSpringSystem<N>
Builds a mass-spring based deformable body from this description.