Multibody

Struct Multibody 

pub struct Multibody<N>
where N: RealField + Copy,
{ /* private fields */ }
An articulated body simulated using the reduced-coordinates approach.

Implementations

Source

impl<N> Multibody<N>
where N: RealField + Copy,

pub fn user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>

Retrieves a reference to the user-defined user-data attached to this object.

pub fn user_data_mut( &mut self, ) -> Option<&mut (dyn Any + Send + Sync + 'static)>

Retrieves a mutable reference to the user-defined user-data attached to this object.

pub fn set_user_data( &mut self, data: Option<Box<dyn Any + Send + Sync>>, ) -> Option<Box<dyn Any + Send + Sync>>

Sets the user-defined data attached to this object.

pub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>

Replace by None the user-defined data attached to this object and returns the old value.

pub fn root(&self) -> &MultibodyLink<N>

The first link of this multibody.

pub fn root_mut(&mut self) -> &mut MultibodyLink<N>

Mutable reference to the first link of this multibody.

Reference i-th multibody link of this multibody.

Return None if there is less than i + 1 multibody links.

Mutable reference to the multibody link with the given id.

Return None if the given id does not identifies a multibody link part of self.

The links of this multibody with the given name.

The number of links on this multibody.

Iterator through all the links of this multibody.

All link are guaranteed to be yielded before its descendant.

Mutable iterator through all the links of this multibody.

All link are guaranteed to be yielded before its descendant.

pub fn damping( &self, ) -> &Matrix<N, Dynamic, Const<1>, VecStorage<N, Dynamic, Const<1>>>

The vector of damping applied to this multibody.

pub fn damping_mut( &mut self, ) -> &mut Matrix<N, Dynamic, Const<1>, VecStorage<N, Dynamic, Const<1>>>

Mutable vector of damping applied to this multibody.

Set the mass of the specified link.

Set the angular inertia of the specified linked, expressed in its local space.

pub fn joint_velocity( &self, link: &MultibodyLink<N>, ) -> Matrix<N, Dynamic, Const<1>, SliceStorage<'_, N, Dynamic, Const<1>, Const<1>, Dynamic>>

The generalized velocity at the joint of the given link.

Convert a force applied to the center of mass of the link rb_id into generalized force.

Convert a force applied to this multibody’s link rb_id center of mass into generalized accelerations.

pub fn inv_mass_mul_unit_joint_force( &self, link: &MultibodyLink<N>, dof_id: usize, force: N, out: &mut [N], )

Convert a generalized force applied to le link rb_id’s degrees of freedom into generalized accelerations.

The joint attaching this link to its parent is assumed to be a unit joint.

pub fn inv_mass_mul_joint_force( &self, link: &MultibodyLink<N>, force: Matrix<N, Dynamic, Const<1>, SliceStorage<'_, N, Dynamic, Const<1>, Const<1>, Dynamic>>, out: &mut [N], )

Convert a generalized force applied to the link rb_id’s degrees of freedom into generalized accelerations.

pub fn augmented_mass( &self, ) -> &Matrix<N, Dynamic, Dynamic, VecStorage<N, Dynamic, Dynamic>>

The augmented mass (inluding gyroscropic and coriolis terms) in world-space of this multibody.

pub fn joint_velocity_mut( &mut self, id: usize, ) -> Matrix<N, Dynamic, Const<1>, SliceStorageMut<'_, N, Dynamic, Const<1>, Const<1>, Dynamic>>

Retrieve the mutable generalized velocities of this link.

pub fn generalized_force( &self, ) -> &Matrix<N, Dynamic, Const<1>, VecStorage<N, Dynamic, Const<1>>>

The generalized forces applied to this multibody at the next timestep.

pub fn generalized_force_mut( &mut self, ) -> &mut Matrix<N, Dynamic, Const<1>, VecStorage<N, Dynamic, Const<1>>>

Mutable reference to the generalized forces applied to this multibody at the next timestep.