pub struct MultibodyLink<N>{ /* private fields */ }Expand description
One link of a multibody.
Implementations
Sourceimpl<N> MultibodyLink<N>
impl<N> MultibodyLink<N>
Sourcepub fn new(
internal_id: usize,
assembly_id: usize,
impulse_id: usize,
parent_internal_id: usize,
dof: Box<dyn Joint<N>>,
parent_shift: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>,
body_shift: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>,
parent_to_world: Isometry<N, Unit<Complex<N>>, 2>,
local_to_world: Isometry<N, Unit<Complex<N>>, 2>,
local_to_parent: Isometry<N, Unit<Complex<N>>, 2>,
local_inertia: Inertia2<N>,
local_com: OPoint<N, Const<2>>,
) -> MultibodyLink<N>
pub fn new( internal_id: usize, assembly_id: usize, impulse_id: usize, parent_internal_id: usize, dof: Box<dyn Joint<N>>, parent_shift: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, body_shift: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, parent_to_world: Isometry<N, Unit<Complex<N>>, 2>, local_to_world: Isometry<N, Unit<Complex<N>>, 2>, local_to_parent: Isometry<N, Unit<Complex<N>>, 2>, local_inertia: Inertia2<N>, local_com: OPoint<N, Const<2>>, ) -> MultibodyLink<N>
Creates a new multibody link.
Sourcepub fn joint(&self) -> &(dyn Joint<N> + 'static)
pub fn joint(&self) -> &(dyn Joint<N> + 'static)
Reference to the joint attaching this link to its parent.
Sourcepub fn joint_mut(&mut self) -> &mut (dyn Joint<N> + 'static)
pub fn joint_mut(&mut self) -> &mut (dyn Joint<N> + 'static)
Mutable reference to the joint attaching this link to its parent.
Sourcepub fn parent_shift(
&self,
) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
pub fn parent_shift( &self, ) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
The shift between this link’s parent and this link joint origin.
Sourcepub fn body_shift(
&self,
) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
pub fn body_shift( &self, ) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
The shift between this link’s joint origin and this link origin.