pub struct GenericNonlinearConstraint<N, Handle>{
pub body1: BodyPartHandle<Handle>,
pub body2: Option<BodyPartHandle<Handle>>,
pub is_angular: bool,
pub dim1: usize,
pub dim2: usize,
pub wj_id1: usize,
pub wj_id2: usize,
pub rhs: N,
pub r: N,
}Expand description
A generic non-linear position constraint.
Fields
body1: BodyPartHandle<Handle>The first body affected by the constraint.
body2: Option<BodyPartHandle<Handle>>The second body affected by the constraint.
is_angular: boolWhether this constraint affects the bodies translation or orientation.
dim1: usizeNumber of degree of freedom of the first body.
dim2: usizeNumber of degree of freedom of the second body.
wj_id1: usizeIndex of the first entry of the constraint jacobian multiplied by the inverse mass of the first body.
wj_id2: usizeIndex of the first entry of the constraint jacobian multiplied by the inverse mass of the second body.
rhs: NThe target position change this constraint must apply.
r: NThe scaling parameter of the SOR-prox method.
Implementations
Sourceimpl<N, Handle> GenericNonlinearConstraint<N, Handle>
impl<N, Handle> GenericNonlinearConstraint<N, Handle>
Sourcepub fn new(
body1: BodyPartHandle<Handle>,
body2: Option<BodyPartHandle<Handle>>,
is_angular: bool,
dim1: usize,
dim2: usize,
wj_id1: usize,
wj_id2: usize,
rhs: N,
r: N,
) -> GenericNonlinearConstraint<N, Handle>
pub fn new( body1: BodyPartHandle<Handle>, body2: Option<BodyPartHandle<Handle>>, is_angular: bool, dim1: usize, dim2: usize, wj_id1: usize, wj_id2: usize, rhs: N, r: N, ) -> GenericNonlinearConstraint<N, Handle>
Initialize a new nonlinear constraint.