pub type ImpulseCache<N> = SecondaryMap<ContactId, N>;Expand description
A cache for impulses resulting from contacts and joints.
Aliased Type
pub struct ImpulseCache<N> { /* private fields */ }pub type ImpulseCache<N> = SecondaryMap<ContactId, N>;A cache for impulses resulting from contacts and joints.
pub struct ImpulseCache<N> { /* private fields */ }