pub struct ActivationStatus<N>{ /* private fields */ }Expand description
The activation status of a body.
This controls whether a body is sleeping or not.
Implementations
Sourceimpl<N> ActivationStatus<N>
impl<N> ActivationStatus<N>
Sourcepub fn default_threshold() -> N
pub fn default_threshold() -> N
The default amount of energy bellow which a body can be put to sleep by nphysics.
Sourcepub fn new_active() -> ActivationStatus<N>
pub fn new_active() -> ActivationStatus<N>
Create a new activation status initialised with the default activation threshold and is active.
Sourcepub fn new_inactive() -> ActivationStatus<N>
pub fn new_inactive() -> ActivationStatus<N>
Create a new activation status initialised with the default activation threshold and is inactive.
Sourcepub fn deactivation_threshold(&self) -> Option<N>
pub fn deactivation_threshold(&self) -> Option<N>
The threshold bellow which the body can be put to sleep.
A value of None indicates that the body cannot sleep.
Sourcepub fn set_deactivation_threshold(&mut self, threshold: Option<N>)
pub fn set_deactivation_threshold(&mut self, threshold: Option<N>)
Set the threshold bellow which the body can be put to sleep.
A value of None prevents the body from sleeping.
Sourcepub fn set_energy(&mut self, energy: N)
pub fn set_energy(&mut self, energy: N)
Sets the current average energy of the body.