Compound

Struct Compound 

pub struct Compound<N>
where N: RealField + Copy,
{ /* private fields */ }
A compound shape with an aabb bounding volume.

A compound shape is a shape composed of the union of several simpler shape. This is the main way of creating a concave shape from convex parts. Each parts can have its own delta transformation to shift or rotate it with regard to the other shapes.

Implementations

Source

impl<N> Compound<N>
where N: RealField + Copy,

pub fn new( shapes: Vec<(Isometry<N, Unit<Complex<N>>, 2>, ShapeHandle<N>)>, ) -> Compound<N>

Builds a new compound shape.

Source

impl<N> Compound<N>
where N: RealField + Copy,

pub fn shapes(&self) -> &[(Isometry<N, Unit<Complex<N>>, 2>, ShapeHandle<N>)]

The shapes of this compound shape.

pub fn bvt(&self) -> &BVT<usize, AABB<N>>

The optimization structure used by this compound shape.

pub fn aabb(&self) -> &AABB<N>

The AABB of this compound in its local-space.

pub fn bounding_volumes(&self) -> &[AABB<N>]

The shapes bounding volumes.

pub fn aabb_at(&self, i: usize) -> &AABB<N>

The AABB of the i-th shape compositing this compound.

pub fn subshape_feature_id(&self, fid: FeatureId) -> (usize, FeatureId)

Transforms a FeatureId of this compound into a pair containing the index of the subshape containing this feature, and the corresponding FeatureId on this subshape.