ConvexPolygonalFeature

Struct ConvexPolygonalFeature 

pub struct ConvexPolygonalFeature<N>
where N: RealField + Copy,
{ pub vertices: [OPoint<N, Const<2>>; 2], pub nvertices: usize, pub normal: Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>, pub feature_id: FeatureId, pub vertices_id: [FeatureId; 2], }
A feature (face or vertex) of a 2D convex polygon.

Fields

vertices: [OPoint<N, Const<2>>; 2]

The vertices of this face.

nvertices: usize

Number of vertices in vertices to be considered.

normal: Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>

The normal of this feature if it is an edge.

feature_id: FeatureId

The shape-dependent identifier of this feature.

vertices_id: [FeatureId; 2]

The shape-dependent indentifier of each vertex of this feature.

Implementations

Source

impl<N> ConvexPolygonalFeature<N>
where N: RealField + Copy,

pub fn new() -> ConvexPolygonalFeature<N>

Creates a new empty convex polygonal faces.

pub fn clear(&mut self)

Removes all the vertices, normals, and feature IDs of this feature.

pub fn transform_by(&mut self, m: &Isometry<N, Unit<Complex<N>>, 2>)

Transforms all the vertices and normal of this feature by the given isometry.

pub fn push(&mut self, pt: OPoint<N, Const<2>>, id: FeatureId)

Adds a vertex to this face.

It is not checked whether pt breaks the convexity of the polyhedral face.

pub fn nvertices(&self) -> usize

The number of vertices of this face.

pub fn vertices(&self) -> &[OPoint<N, Const<2>>]

The vertices of this convex polygonal face.

pub fn set_normal( &mut self, normal: Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, )

Sets the outward normal of this convex polygonal face.

pub fn set_feature_id(&mut self, id: FeatureId)

Sets the identifier of the feature represented by this convex polygon.

pub fn project_point(&self, pt: &OPoint<N, Const<2>>) -> Option<Contact<N>>

Projects a point on this feature.

pub fn clip( &self, other: &ConvexPolygonalFeature<N>, normal: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, prediction: &ContactPrediction<N>, out: &mut Vec<(Contact<N>, FeatureId, FeatureId)>, )

Generate contacts between self and other using polygonal clipping, iif. they both have at least two vertices.

If either self or other has less than two vertices, this does nothing.

pub fn add_contact_to_manifold( &self, other: &ConvexPolygonalFeature<N>, c: Contact<N>, m1: &Isometry<N, Unit<Complex<N>>, 2>, f1: FeatureId, proc1: Option<&dyn ContactPreprocessor<N>>, m2: &Isometry<N, Unit<Complex<N>>, 2>, f2: FeatureId, proc2: Option<&dyn ContactPreprocessor<N>>, manifold: &mut ContactManifold<N>, )

Given a contact between two polygonal features, adds it to a contact manifold.