MassConstraintSystem

Struct MassConstraintSystem 

pub struct MassConstraintSystem<N>
where N: RealField + Copy,
{ /* private fields */ }
A deformable surface using a mass-LengthConstraint model with triangular elements.

Implementations

Source

impl<N> MassConstraintSystem<N>
where N: RealField + Copy,

pub fn from_polyline( polyline: &Polyline<N>, mass: N, stiffness: Option<N>, ) -> MassConstraintSystem<N>

Builds a mass-spring system from a polyline.

pub fn user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>

Retrieves a reference to the user-defined user-data attached to this object.

pub fn user_data_mut( &mut self, ) -> Option<&mut (dyn Any + Send + Sync + 'static)>

Retrieves a mutable reference to the user-defined user-data attached to this object.

pub fn set_user_data( &mut self, data: Option<Box<dyn Any + Send + Sync>>, ) -> Option<Box<dyn Any + Send + Sync>>

Sets the user-defined data attached to this object.

pub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>

Replace by None the user-defined data attached to this object and returns the old value.

pub fn add_constraint( &mut self, node1: usize, node2: usize, stiffness: Option<N>, )

Add one constraint to this mass-constraint system.

pub fn generate_neighbor_constraints(&mut self, stiffness: Option<N>)

Generate additional constraints between nodes that are transitively neighbors.

Given three nodes a, b, c, if a constraint exists between a and b, and between b and c, then a constraint between a and c is created if it does not already exists.

pub fn num_nodes(&self) -> usize

The number of nodes of this mass-constraint system.

pub fn mass(&self) -> N

The total mass of this body.

pub fn set_warmstart_coefficient(&mut self, coeff: N)

The coefficient used for warm-starting the resolution of internal constraints of this soft body (default: 0.5).

pub fn warmstart_coefficient(&self) -> N

The coefficient used for warm-starting the resolution of internal constraints of this soft body (default: 0.5).

pub fn set_node_kinematic(&mut self, i: usize, is_kinematic: bool)

Restrict the specified node acceleration to always be zero so it can be controlled manually by the user at the velocity level.

pub fn clear_kinematic_nodes(&mut self)

Mark all nodes as non-kinematic.

pub fn set_plasticity(&mut self, strain_threshold: N, creep: N, max_force: N)

Sets the plastic properties of this mass-constraint system.