Segment

Struct Segment 

#[repr(C)]
pub struct Segment<N>
where N: RealField + Copy,
{ pub a: OPoint<N, Const<2>>, pub b: OPoint<N, Const<2>>, }
A segment shape.

Fields

a: OPoint<N, Const<2>>

The segment first point.

b: OPoint<N, Const<2>>

The segment second point.

Implementations

Source

impl<N> Segment<N>
where N: RealField + Copy,

pub fn new(a: OPoint<N, Const<2>>, b: OPoint<N, Const<2>>) -> Segment<N>

Creates a new segment from two points.

pub fn from_array(arr: &[OPoint<N, Const<2>>; 2]) -> &Segment<N>

Creates the reference to a segment from the reference to an array of two points.

Source

impl<N> Segment<N>
where N: RealField + Copy,

pub fn a(&self) -> &OPoint<N, Const<2>>

👎Deprecated:

use the self.a public field directly.

The first point of this segment.

pub fn b(&self) -> &OPoint<N, Const<2>>

👎Deprecated:

use the self.b public field directly.

The second point of this segment.

Source

impl<N> Segment<N>
where N: RealField + Copy,

pub fn scaled_direction( &self, ) -> Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>

The direction of this segment scaled by its length.

Points from self.a toward self.b.

pub fn length(&self) -> N

The length of this segment.

pub fn swap(&mut self)

Swaps the two vertices of this segment.

pub fn direction( &self, ) -> Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>

The unit direction of this segment.

Points from self.a() toward self.b(). Returns None is both points are equal.

pub fn scaled_normal( &self, ) -> Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>

In 2D, the not-normalized counterclockwise normal of this segment.

pub fn normal( &self, ) -> Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>

In 2D, the normalized counterclockwise normal of this segment.

pub fn transformed(&self, m: &Isometry<N, Unit<Complex<N>>, 2>) -> Segment<N>

Applies the isometry m to the vertices of this segment and returns the resulting segment.

pub fn point_at( &self, location: &SegmentPointLocation<N>, ) -> OPoint<N, Const<2>>

Computes the point at the given location.

pub fn tangent_cone_contains_dir( &self, feature: FeatureId, m: &Isometry<N, Unit<Complex<N>>, 2>, dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, ) -> bool

Checks that the given direction in world-space is on the tangent cone of the given feature.