Triangle

Struct Triangle 

#[repr(C)]
pub struct Triangle<N>
where N: RealField + Copy,
{ pub a: OPoint<N, Const<2>>, pub b: OPoint<N, Const<2>>, pub c: OPoint<N, Const<2>>, }
A triangle shape.

Fields

a: OPoint<N, Const<2>>

The triangle first point.

b: OPoint<N, Const<2>>

The triangle second point.

c: OPoint<N, Const<2>>

The triangle third point.

Implementations

Source

impl<N> Triangle<N>
where N: RealField + Copy,

pub fn new( a: OPoint<N, Const<2>>, b: OPoint<N, Const<2>>, c: OPoint<N, Const<2>>, ) -> Triangle<N>

Creates a triangle from three points.

pub fn from_array(arr: &[OPoint<N, Const<2>>; 3]) -> &Triangle<N>

Creates the reference to a triangle from the reference to an array of three points.

pub fn a(&self) -> &OPoint<N, Const<2>>

👎Deprecated:

use the self.a public field directly.

The fist point of this triangle.

pub fn b(&self) -> &OPoint<N, Const<2>>

👎Deprecated:

use the self.b public field directly.

The second point of this triangle.

pub fn c(&self) -> &OPoint<N, Const<2>>

👎Deprecated:

use the self.c public field directly.

The third point of this triangle.

pub fn vertices(&self) -> &[OPoint<N, Const<2>>; 3]

Reference to an array containing the three vertices of this triangle.

pub fn normal( &self, ) -> Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>

The normal of this triangle assuming it is oriented ccw.

The normal points such that it is collinear to AB × AC (where × denotes the cross product).

pub fn edges(&self) -> [Segment<N>; 3]

The three edges of this triangle: [AB, BC, CA].

pub fn transformed(&self, m: &Isometry<N, Unit<Complex<N>>, 2>) -> Triangle<N>

Returns a new triangle with vertices transformed by m.

pub fn edges_scaled_directions( &self, ) -> [Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>; 3]

The three edges scaled directions of this triangle: [B - A, C - B, A - C].

pub fn scaled_normal( &self, ) -> Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>

A vector normal of this triangle.

The vector points such that it is collinear to AB × AC (where × denotes the cross product).

pub fn extents_on_dir( &self, dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, ) -> (N, N)

Computes the extents of this triangle on the given direction.

This computes the min and max values of the dot products between each vertex of this triangle and dir.