pub struct CartesianJoint<N>{ /* private fields */ }Expand description
A joint that allows only all the translational degrees of freedom between two multibody links.
Implementations
Sourceimpl<N> CartesianJoint<N>
impl<N> CartesianJoint<N>
Sourcepub fn new(
position: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>,
) -> CartesianJoint<N>
pub fn new( position: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> CartesianJoint<N>
Create a cartesian joint with an initial position given by position.