pub enum MaterialCombineMode {
Average,
Min,
Multiply,
Max,
Lookup,
}Expand description
The way the friction and restitution coefficients of two materials should be combined.
Variants
Average
Combination by averaging the coefficients from both materials.
Min
Combination by taking the min of the coefficients from both materials.
Has precedence over the Average combine mode.
Multiply
Combination by multiplying the coefficients from both materials.
Has precedence over the Min and Average combine modes.
Max
Combination by taking the max the coefficients from both materials.
Has precedence over all other combine mode.
Lookup
Should not be used directly. This is set as a result of the combine method
if the combination was performed by a lookup on the MaterialsCoefficientsTable.
Implementations
Sourceimpl MaterialCombineMode
impl MaterialCombineMode
Sourcepub fn combine<N>(
a: (N, MaterialCombineMode),
b: (N, MaterialCombineMode),
) -> (N, MaterialCombineMode)
pub fn combine<N>( a: (N, MaterialCombineMode), b: (N, MaterialCombineMode), ) -> (N, MaterialCombineMode)
Combines two coefficients using their associated MaterialCombineMode.
The combine mode with the highest precedence among the two provided determines
the actual formula used. Precedences are described on the MaterialCombineMode enum.