pub struct DefaultBodySet<N>{ /* private fields */ }Expand description
The default set containing all the bodies added to the world.
It is based on an arena using generational indices to avoid the ABA problem.
Implementations
Sourceimpl<N> DefaultBodySet<N>
impl<N> DefaultBodySet<N>
Sourcepub fn new() -> DefaultBodySet<N>
pub fn new() -> DefaultBodySet<N>
Creates an empty set.
Sourcepub fn insert_boxed(&mut self, body: Box<dyn Body<N>>) -> Index
pub fn insert_boxed(&mut self, body: Box<dyn Body<N>>) -> Index
Adds a body (represented as a boxed trait-object) to this set.
Sourcepub fn remove(&mut self, to_remove: Index) -> Option<Box<dyn Body<N>>>
pub fn remove(&mut self, to_remove: Index) -> Option<Box<dyn Body<N>>>
Removes a body from this set.
Sourcepub fn get(&self, handle: Index) -> Option<&(dyn Body<N> + 'static)>
pub fn get(&self, handle: Index) -> Option<&(dyn Body<N> + 'static)>
Gets a reference to the body identified by handle.
Sourcepub fn get_mut(&mut self, handle: Index) -> Option<&mut (dyn Body<N> + 'static)>
pub fn get_mut(&mut self, handle: Index) -> Option<&mut (dyn Body<N> + 'static)>
Gets a mutable reference to the body identified by handle.
Sourcepub fn iter(&self) -> impl Iterator<Item = (Index, &(dyn Body<N> + 'static))>
pub fn iter(&self) -> impl Iterator<Item = (Index, &(dyn Body<N> + 'static))>
Iterate through all the bodies and their handles.
Sourcepub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (Index, &mut (dyn Body<N> + 'static))>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (Index, &mut (dyn Body<N> + 'static))>
Mutably iterate through all the bodies and their handles.
Sourcepub fn rigid_body(&self, handle: Index) -> Option<&RigidBody<N>>
pub fn rigid_body(&self, handle: Index) -> Option<&RigidBody<N>>
Gets the rigid body identified by handle.
Returns None if the body does not exists, of if it exists but is not a rigid body.
Sourcepub fn rigid_body_mut(&mut self, handle: Index) -> Option<&mut RigidBody<N>>
pub fn rigid_body_mut(&mut self, handle: Index) -> Option<&mut RigidBody<N>>
Gets a mutable reference to the rigid body identified by handle.
Returns None if the body does not exists, of if it exists but is not a rigid body.
Sourcepub fn multibody(&self, handle: Index) -> Option<&Multibody<N>>
pub fn multibody(&self, handle: Index) -> Option<&Multibody<N>>
Gets the multibody identified by handle.
Returns None if the body does not exists, of if it exists but is not a multibody.
Sourcepub fn multibody_mut(&mut self, handle: Index) -> Option<&mut Multibody<N>>
pub fn multibody_mut(&mut self, handle: Index) -> Option<&mut Multibody<N>>
Gets a mutable reference to the multibody identified by handle.
Returns None if the body does not exists, of if it exists but is not a multibody.