pub struct FEMSurfaceDesc<'a, N>{ /* private fields */ }Expand description
A builder for FEMSurface bodies.
Implementations
Sourceimpl<'a, N> FEMSurfaceDesc<'a, N>
impl<'a, N> FEMSurfaceDesc<'a, N>
Sourcepub fn new(
vertices: &'a [OPoint<N, Const<2>>],
triangles: &'a [OPoint<usize, Const<3>>],
) -> FEMSurfaceDesc<'a, N>
pub fn new( vertices: &'a [OPoint<N, Const<2>>], triangles: &'a [OPoint<usize, Const<3>>], ) -> FEMSurfaceDesc<'a, N>
Create a surface form the given tiangles.
Sourcepub fn quad(subdiv_x: usize, subdiv_y: usize) -> FEMSurfaceDesc<'a, N>
pub fn quad(subdiv_x: usize, subdiv_y: usize) -> FEMSurfaceDesc<'a, N>
Create a surface form the given triangles.
Sourcepub fn clear_kinematic_nodes(&mut self) -> &mut FEMSurfaceDesc<'a, N>
pub fn clear_kinematic_nodes(&mut self) -> &mut FEMSurfaceDesc<'a, N>
Mark all nodes as non-kinematic.
Sourcepub fn user_data(self, data: impl UserData) -> FEMSurfaceDesc<'a, N>
pub fn user_data(self, data: impl UserData) -> FEMSurfaceDesc<'a, N>
Sets a user-data to be attached to the object being built.
Sourcepub fn set_user_data(
&mut self,
data: Option<impl UserData>,
) -> &mut FEMSurfaceDesc<'a, N>
pub fn set_user_data( &mut self, data: Option<impl UserData>, ) -> &mut FEMSurfaceDesc<'a, N>
Sets the user-data to be attached to the object being built.
Sourcepub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
pub fn get_user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
Reference to the user-data to be attached to the object being built.
pub fn plasticity( self, strain_threshold: N, creep: N, max_force: N, ) -> FEMSurfaceDesc<'a, N>
pub fn set_plasticity( &mut self, strain_threshold: N, creep: N, max_force: N, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn kinematic_nodes(self, nodes: &[usize]) -> FEMSurfaceDesc<'a, N>
pub fn set_nodes_kinematic( &mut self, nodes: &[usize], ) -> &mut FEMSurfaceDesc<'a, N>
pub fn translation( self, vector: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> FEMSurfaceDesc<'a, N>
pub fn set_translation( &mut self, vector: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn gravity_enabled(self, gravity_enabled: bool) -> FEMSurfaceDesc<'a, N>
pub fn enable_gravity( &mut self, gravity_enabled: bool, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn scale( self, scale: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> FEMSurfaceDesc<'a, N>
pub fn set_scale( &mut self, scale: Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn young_modulus(self, young_modulus: N) -> FEMSurfaceDesc<'a, N>
pub fn set_young_modulus( &mut self, young_modulus: N, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn poisson_ratio(self, poisson_ratio: N) -> FEMSurfaceDesc<'a, N>
pub fn set_poisson_ratio( &mut self, poisson_ratio: N, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn sleep_threshold( self, sleep_threshold: Option<N>, ) -> FEMSurfaceDesc<'a, N>
pub fn set_sleep_threshold( &mut self, sleep_threshold: Option<N>, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn mass_damping(self, mass_damping: N) -> FEMSurfaceDesc<'a, N>
pub fn set_mass_damping( &mut self, mass_damping: N, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn stiffness_damping(self, stiffness_damping: N) -> FEMSurfaceDesc<'a, N>
pub fn set_stiffness_damping( &mut self, stiffness_damping: N, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn density(self, density: N) -> FEMSurfaceDesc<'a, N>
pub fn set_density(&mut self, density: N) -> &mut FEMSurfaceDesc<'a, N>
pub fn status(self, status: BodyStatus) -> FEMSurfaceDesc<'a, N>
pub fn set_status(&mut self, status: BodyStatus) -> &mut FEMSurfaceDesc<'a, N>
pub fn position( self, position: Isometry<N, Unit<Complex<N>>, 2>, ) -> FEMSurfaceDesc<'a, N>
pub fn set_position( &mut self, position: Isometry<N, Unit<Complex<N>>, 2>, ) -> &mut FEMSurfaceDesc<'a, N>
pub fn get_plasticity_strain_threshold(&self) -> N
pub fn get_plasticity_creep(&self) -> N
pub fn get_plasticity_max_force(&self) -> N
pub fn get_kinematic_nodes(&self) -> &[usize]
pub fn get_translation( &self, ) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
pub fn is_gravity_enabled(&self) -> bool
pub fn get_young_modulus(&self) -> N
pub fn get_poisson_ratio(&self) -> N
pub fn get_sleep_threshold(&self) -> Option<N>
pub fn get_mass_damping(&self) -> N
pub fn get_stiffness_damping(&self) -> N
pub fn get_density(&self) -> N
pub fn get_status(&self) -> BodyStatus
pub fn get_position(&self) -> &Isometry<N, Unit<Complex<N>>, 2>
pub fn get_scale( &self, ) -> &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>
Sourcepub fn build(&self) -> FEMSurface<N>
pub fn build(&self) -> FEMSurface<N>
Builds a finite-element based deformable body from this description.