pub struct Compound<N>{ /* private fields */ }Expand description
A compound shape with an aabb bounding volume.
A compound shape is a shape composed of the union of several simpler shape. This is the main way of creating a concave shape from convex parts. Each parts can have its own delta transformation to shift or rotate it with regard to the other shapes.
Implementations
Sourceimpl<N> Compound<N>
impl<N> Compound<N>
Sourcepub fn shapes(&self) -> &[(Isometry<N, Unit<Complex<N>>, 2>, ShapeHandle<N>)]
pub fn shapes(&self) -> &[(Isometry<N, Unit<Complex<N>>, 2>, ShapeHandle<N>)]
The shapes of this compound shape.
Sourcepub fn bvt(&self) -> &BVT<usize, AABB<N>>
pub fn bvt(&self) -> &BVT<usize, AABB<N>>
The optimization structure used by this compound shape.
Sourcepub fn bounding_volumes(&self) -> &[AABB<N>]
pub fn bounding_volumes(&self) -> &[AABB<N>]
The shapes bounding volumes.
Sourcepub fn aabb_at(&self, i: usize) -> &AABB<N>
pub fn aabb_at(&self, i: usize) -> &AABB<N>
The AABB of the i-th shape compositing this compound.
Sourcepub fn subshape_feature_id(&self, fid: FeatureId) -> (usize, FeatureId)
pub fn subshape_feature_id(&self, fid: FeatureId) -> (usize, FeatureId)
Transforms a FeatureId of this compound into a pair containing the index of the subshape containing this feature, and the corresponding FeatureId on this subshape.