pub struct ConvexPolygonalFeature<N>{
pub vertices: [OPoint<N, Const<2>>; 2],
pub nvertices: usize,
pub normal: Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>,
pub feature_id: FeatureId,
pub vertices_id: [FeatureId; 2],
}Expand description
A feature (face or vertex) of a 2D convex polygon.
Fields
vertices: [OPoint<N, Const<2>>; 2]The vertices of this face.
nvertices: usizeNumber of vertices in vertices to be considered.
normal: Option<Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>>The normal of this feature if it is an edge.
feature_id: FeatureIdThe shape-dependent identifier of this feature.
vertices_id: [FeatureId; 2]The shape-dependent indentifier of each vertex of this feature.
Implementations
Sourceimpl<N> ConvexPolygonalFeature<N>
impl<N> ConvexPolygonalFeature<N>
Sourcepub fn new() -> ConvexPolygonalFeature<N>
pub fn new() -> ConvexPolygonalFeature<N>
Creates a new empty convex polygonal faces.
Sourcepub fn transform_by(&mut self, m: &Isometry<N, Unit<Complex<N>>, 2>)
pub fn transform_by(&mut self, m: &Isometry<N, Unit<Complex<N>>, 2>)
Transforms all the vertices and normal of this feature by the given isometry.
Sourcepub fn push(&mut self, pt: OPoint<N, Const<2>>, id: FeatureId)
pub fn push(&mut self, pt: OPoint<N, Const<2>>, id: FeatureId)
Adds a vertex to this face.
It is not checked whether pt breaks the convexity of the polyhedral face.
Sourcepub fn set_normal(
&mut self,
normal: Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>,
)
pub fn set_normal( &mut self, normal: Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, )
Sets the outward normal of this convex polygonal face.
Sourcepub fn set_feature_id(&mut self, id: FeatureId)
pub fn set_feature_id(&mut self, id: FeatureId)
Sets the identifier of the feature represented by this convex polygon.
Sourcepub fn project_point(&self, pt: &OPoint<N, Const<2>>) -> Option<Contact<N>>
pub fn project_point(&self, pt: &OPoint<N, Const<2>>) -> Option<Contact<N>>
Projects a point on this feature.
Sourcepub fn clip(
&self,
other: &ConvexPolygonalFeature<N>,
normal: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>,
prediction: &ContactPrediction<N>,
out: &mut Vec<(Contact<N>, FeatureId, FeatureId)>,
)
pub fn clip( &self, other: &ConvexPolygonalFeature<N>, normal: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, prediction: &ContactPrediction<N>, out: &mut Vec<(Contact<N>, FeatureId, FeatureId)>, )
Generate contacts between self and other using polygonal clipping, iif. they both have at least
two vertices.
If either self or other has less than two vertices, this does nothing.
Sourcepub fn add_contact_to_manifold(
&self,
other: &ConvexPolygonalFeature<N>,
c: Contact<N>,
m1: &Isometry<N, Unit<Complex<N>>, 2>,
f1: FeatureId,
proc1: Option<&dyn ContactPreprocessor<N>>,
m2: &Isometry<N, Unit<Complex<N>>, 2>,
f2: FeatureId,
proc2: Option<&dyn ContactPreprocessor<N>>,
manifold: &mut ContactManifold<N>,
)
pub fn add_contact_to_manifold( &self, other: &ConvexPolygonalFeature<N>, c: Contact<N>, m1: &Isometry<N, Unit<Complex<N>>, 2>, f1: FeatureId, proc1: Option<&dyn ContactPreprocessor<N>>, m2: &Isometry<N, Unit<Complex<N>>, 2>, f2: FeatureId, proc2: Option<&dyn ContactPreprocessor<N>>, manifold: &mut ContactManifold<N>, )
Given a contact between two polygonal features, adds it to a contact manifold.