pub struct MassConstraintSystem<N>{ /* private fields */ }Expand description
A deformable surface using a mass-LengthConstraint model with triangular elements.
Implementations
Sourceimpl<N> MassConstraintSystem<N>
impl<N> MassConstraintSystem<N>
Sourcepub fn from_polyline(
polyline: &Polyline<N>,
mass: N,
stiffness: Option<N>,
) -> MassConstraintSystem<N>
pub fn from_polyline( polyline: &Polyline<N>, mass: N, stiffness: Option<N>, ) -> MassConstraintSystem<N>
Builds a mass-spring system from a polyline.
Sourcepub fn user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
pub fn user_data(&self) -> Option<&(dyn Any + Send + Sync + 'static)>
Retrieves a reference to the user-defined user-data attached to this object.
Sourcepub fn user_data_mut(
&mut self,
) -> Option<&mut (dyn Any + Send + Sync + 'static)>
pub fn user_data_mut( &mut self, ) -> Option<&mut (dyn Any + Send + Sync + 'static)>
Retrieves a mutable reference to the user-defined user-data attached to this object.
Sourcepub fn set_user_data(
&mut self,
data: Option<Box<dyn Any + Send + Sync>>,
) -> Option<Box<dyn Any + Send + Sync>>
pub fn set_user_data( &mut self, data: Option<Box<dyn Any + Send + Sync>>, ) -> Option<Box<dyn Any + Send + Sync>>
Sets the user-defined data attached to this object.
Sourcepub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>
pub fn take_user_data(&mut self) -> Option<Box<dyn Any + Send + Sync>>
Replace by None the user-defined data attached to this object and returns the old value.
Sourcepub fn add_constraint(
&mut self,
node1: usize,
node2: usize,
stiffness: Option<N>,
)
pub fn add_constraint( &mut self, node1: usize, node2: usize, stiffness: Option<N>, )
Add one constraint to this mass-constraint system.
Sourcepub fn generate_neighbor_constraints(&mut self, stiffness: Option<N>)
pub fn generate_neighbor_constraints(&mut self, stiffness: Option<N>)
Generate additional constraints between nodes that are transitively neighbors.
Given three nodes a, b, c, if a constraint exists between a and b, and between b and c,
then a constraint between a and c is created if it does not already exists.
Sourcepub fn set_warmstart_coefficient(&mut self, coeff: N)
pub fn set_warmstart_coefficient(&mut self, coeff: N)
The coefficient used for warm-starting the resolution of internal constraints of this soft body (default: 0.5).
Sourcepub fn warmstart_coefficient(&self) -> N
pub fn warmstart_coefficient(&self) -> N
The coefficient used for warm-starting the resolution of internal constraints of this soft body (default: 0.5).
Sourcepub fn set_node_kinematic(&mut self, i: usize, is_kinematic: bool)
pub fn set_node_kinematic(&mut self, i: usize, is_kinematic: bool)
Restrict the specified node acceleration to always be zero so it can be controlled manually by the user at the velocity level.
Sourcepub fn clear_kinematic_nodes(&mut self)
pub fn clear_kinematic_nodes(&mut self)
Mark all nodes as non-kinematic.
Sourcepub fn set_plasticity(&mut self, strain_threshold: N, creep: N, max_force: N)
pub fn set_plasticity(&mut self, strain_threshold: N, creep: N, max_force: N)
Sets the plastic properties of this mass-constraint system.