pub trait SupportMap<N>{
// Required method
fn local_support_point(
&self,
dir: &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>,
) -> OPoint<N, Const<2>>;
// Provided methods
fn local_support_point_toward(
&self,
dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>,
) -> OPoint<N, Const<2>> { ... }
fn support_point(
&self,
transform: &Isometry<N, Unit<Complex<N>>, 2>,
dir: &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>,
) -> OPoint<N, Const<2>> { ... }
fn support_point_toward(
&self,
transform: &Isometry<N, Unit<Complex<N>>, 2>,
dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>,
) -> OPoint<N, Const<2>> { ... }
}Expand description
Traits of convex shapes representable by a support mapping function.
Parameters:
- V - type of the support mapping direction argument and of the returned point.
Required Methods
fn local_support_point( &self, dir: &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> OPoint<N, Const<2>>
Provided Methods
Sourcefn local_support_point_toward(
&self,
dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>,
) -> OPoint<N, Const<2>>
fn local_support_point_toward( &self, dir: &Unit<Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>>, ) -> OPoint<N, Const<2>>
Same as self.local_support_point except that dir is normalized.
fn support_point( &self, transform: &Isometry<N, Unit<Complex<N>>, 2>, dir: &Matrix<N, Const<nalgebra::::base::dimension::U2::{constant#0}>, Const<1>, ArrayStorage<N, 2, 1>>, ) -> OPoint<N, Const<2>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".